#[cfg(not(feature="no_mem_manip"))]
#[link(name="c")]
extern
{
   /// Copies the values of n bytes from the location pointed to by
   /// src directly to the memory block pointed to by dest.
   ///
   /// The underlying type of the objects pointed to by both the src
   /// and dest pointers are irrelevant for this function; The
   /// result is a binary copy of the data.
   ///
   /// The function does not check for any terminating null character
   /// in source - it always copies exactly n bytes.
   ///
   /// To avoid overflows, the size of the arrays pointed to by both
   /// the dest and src parameters, shall be at least n bytes,
   /// and should not overlap (for overlapping memory blocks, memmove
   /// is a safer approach).
   pub fn memcpy(dest: *mut u8, src: *const u8, n: usize);

   /// Copies the values of n bytes from the location pointed by src
   /// to the memory block pointed by dest. Copying takes place
   /// as if an intermediate buffer were used, allowing the dest
   /// and src to overlap.
   ///
   /// The underlying type of the objects pointed by both the src and
   /// dest pointers are irrelevant for this function; The result
   /// is a binary copy of the data.
   ///
   /// The function does not check for any terminating null character
   /// in source - it always copies exactly n bytes.
   ///
   /// To avoid overflows, the size of the arrays pointed by both
   /// the dest and src parameters, shall be at least n bytes.
   pub fn memmove(dest: *mut u8, src: *const u8, n: usize);


   /// Compares the first n bytes of the block of memory pointed by
   /// s1 to the first num bytes pointed by s2, returning zero if
   /// they all match or a value different from zero representing which
   /// is greater if they do not.
   ///
   /// Notice that, unlike strcmp, the function does not stop comparing
   /// after finding a null character.
   pub fn memcmp(s1: *const u8, s2: *const u8, n: usize);


   /// Sets the first n bytes of the block of memory pointed by s
   /// to the specified value c (interpreted as an unsigned char).
   pub fn memset(s: *mut u8, c: i32, n: usize);
}
